otcextensions.sdk.cbr.v3.vault
==============================

.. automodule:: otcextensions.sdk.cbr.v3.vault

The CBR Vault Class
-------------------

The ``Vault`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.cbr.v3.vault.Vault
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.vault.BillingSpec
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.vault.BillingExtraInfoSpec
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.vault.ResourceSpec
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.vault.ResourceExtraInfoSpec
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.vault.VolumeSpec
   :members:

